==> syncthingtray-qt6-debug-2.0.4-1-x86_64.pkg.tar.zst: usr/src/debug/syncthingtray-qt6/syncthingtray/cli/syncthingctl-qt6_autogen/UEZOVR3B67/qrc_js.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // helper.js
  0x0,0x0,0x3,0x50,
  0x66,
  0x75,0x6e,0x63,0x74,0x69,0x6f,0x6e,0x20,0x66,0x69,0x6e,0x64,0x46,0x6f,0x6c,0x64,
  0x65,0x72,0x28,0x69,0x64,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,0x61,0x72,
  0x20,0x66,0x6f,0x6c,0x64,0x65,0x72,0x73,0x20,0x3d,0x20,0x63,0x6f,0x6e,0x66,0x69,
  0x67,0x2e,0x66,0x6f,0x6c,0x64,0x65,0x72,0x73,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,
  0x6f,0x72,0x20,0x28,0x76,0x61,0x72,0x20,0x69,0x20,0x3d,0x20,0x30,0x2c,0x20,0x63,
  0x6f,0x75,0x6e,0x74,0x20,0x3d,0x20,0x66,0x6f,0x6c,0x64,0x65,0x72,0x73,0x2e,0x6c,
  0x65,0x6e,0x67,0x74,0x68,0x3b,0x20,0x69,0x20,0x21,0x3d,0x3d,0x20,0x63,0x6f,0x75,
  0x6e,0x74,0x3b,0x20,0x2b,0x2b,0x69,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x76,0x61,0x72,0x20,0x66,0x6f,0x6c,0x64,0x65,0x72,0x20,0x3d,0x20,
  0x66,0x6f,0x6c,0x64,0x65,0x72,0x73,0x5b,0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x69,0x66,0x20,0x28,0x66,0x6f,0x6c,0x64,0x65,0x72,0x2e,0x69,
  0x64,0x20,0x3d,0x3d,0x3d,0x20,0x69,0x64,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x72,0x65,0x74,0x75,0x72,0x6e,0x20,0x66,
  0x6f,0x6c,0x64,0x65,0x72,0x3b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,
  0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x7d,0xa,0xa,0x66,0x75,0x6e,0x63,0x74,0x69,
  0x6f,0x6e,0x20,0x66,0x69,0x6e,0x64,0x44,0x65,0x76,0x69,0x63,0x65,0x28,0x6e,0x61,
  0x6d,0x65,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,0x61,0x72,0x20,0x64,0x65,
  0x76,0x69,0x63,0x65,0x73,0x20,0x3d,0x20,0x63,0x6f,0x6e,0x66,0x69,0x67,0x2e,0x64,
  0x65,0x76,0x69,0x63,0x65,0x73,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,0x6f,0x72,0x20,
  0x28,0x76,0x61,0x72,0x20,0x69,0x20,0x3d,0x20,0x30,0x2c,0x20,0x63,0x6f,0x75,0x6e,
  0x74,0x20,0x3d,0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x73,0x2e,0x6c,0x65,0x6e,0x67,
  0x74,0x68,0x3b,0x20,0x69,0x20,0x21,0x3d,0x3d,0x20,0x63,0x6f,0x75,0x6e,0x74,0x3b,
  0x20,0x2b,0x2b,0x69,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x76,0x61,0x72,0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x20,0x3d,0x20,0x64,0x65,0x76,
  0x69,0x63,0x65,0x73,0x5b,0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x69,0x66,0x20,0x28,0x64,0x65,0x76,0x69,0x63,0x65,0x2e,0x6e,0x61,0x6d,0x65,
  0x20,0x3d,0x3d,0x3d,0x20,0x6e,0x61,0x6d,0x65,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x72,0x65,0x74,0x75,0x72,0x6e,0x20,
  0x64,0x65,0x76,0x69,0x63,0x65,0x3b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x7d,0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x7d,0xa,0xa,0x66,0x75,0x6e,0x63,0x74,
  0x69,0x6f,0x6e,0x20,0x66,0x69,0x6e,0x64,0x44,0x65,0x76,0x69,0x63,0x65,0x42,0x79,
  0x49,0x64,0x28,0x69,0x64,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,0x61,0x72,
  0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x73,0x20,0x3d,0x20,0x63,0x6f,0x6e,0x66,0x69,
  0x67,0x2e,0x64,0x65,0x76,0x69,0x63,0x65,0x73,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,
  0x6f,0x72,0x20,0x28,0x76,0x61,0x72,0x20,0x69,0x20,0x3d,0x20,0x30,0x2c,0x20,0x63,
  0x6f,0x75,0x6e,0x74,0x20,0x3d,0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x73,0x2e,0x6c,
  0x65,0x6e,0x67,0x74,0x68,0x3b,0x20,0x69,0x20,0x21,0x3d,0x3d,0x20,0x63,0x6f,0x75,
  0x6e,0x74,0x3b,0x20,0x2b,0x2b,0x69,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x76,0x61,0x72,0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x20,0x3d,0x20,
  0x64,0x65,0x76,0x69,0x63,0x65,0x73,0x5b,0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x69,0x66,0x20,0x28,0x64,0x65,0x76,0x69,0x63,0x65,0x2e,0x64,
  0x65,0x76,0x69,0x63,0x65,0x49,0x44,0x20,0x3d,0x3d,0x3d,0x20,0x6e,0x61,0x6d,0x65,
  0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x72,0x65,0x74,0x75,0x72,0x6e,0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x3b,0xa,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x7d,
  0xa,0xa,0x66,0x75,0x6e,0x63,0x74,0x69,0x6f,0x6e,0x20,0x61,0x73,0x73,0x69,0x67,
  0x6e,0x49,0x66,0x50,0x72,0x65,0x73,0x65,0x6e,0x74,0x28,0x6f,0x62,0x6a,0x65,0x63,
  0x74,0x2c,0x20,0x70,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x2c,0x20,0x76,0x61,0x6c,
  0x75,0x65,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x69,0x66,0x20,0x28,0x21,0x6f,
  0x62,0x6a,0x65,0x63,0x74,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x72,0x65,0x74,0x75,0x72,0x6e,0x3b,0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,
  0x20,0x20,0x20,0x6f,0x62,0x6a,0x65,0x63,0x74,0x5b,0x70,0x72,0x6f,0x70,0x65,0x72,
  0x74,0x79,0x5d,0x20,0x3d,0x20,0x76,0x61,0x6c,0x75,0x65,0x3b,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // js
  0x0,0x2,
  0x0,0x0,0x7,0x13,
  0x0,0x6a,
  0x0,0x73,
    // helper.js
  0x0,0x9,
  0x3,0x6c,0x88,0x93,
  0x0,0x68,
  0x0,0x65,0x0,0x6c,0x0,0x70,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,0x6a,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9a,0xe0,0x50,0x9,0x48,
  // :/js
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9a,0xe0,0x50,0x9,0x48,
  // :/js/helper.js
  0x0,0x0,0x0,0xa,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0xe0,0x50,0x9,0x48,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_js)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_js)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_js)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_js)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_js)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_js)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> syncthingtray-qt6-debug-2.0.6-1-x86_64.pkg.tar.zst: usr/src/debug/syncthingtray-qt6/syncthingtray/cli/syncthingctl-qt6_autogen/UEZOVR3B67/qrc_js.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // helper.js
  0x0,0x0,0x3,0x50,
  0x66,
  0x75,0x6e,0x63,0x74,0x69,0x6f,0x6e,0x20,0x66,0x69,0x6e,0x64,0x46,0x6f,0x6c,0x64,
  0x65,0x72,0x28,0x69,0x64,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,0x61,0x72,
  0x20,0x66,0x6f,0x6c,0x64,0x65,0x72,0x73,0x20,0x3d,0x20,0x63,0x6f,0x6e,0x66,0x69,
  0x67,0x2e,0x66,0x6f,0x6c,0x64,0x65,0x72,0x73,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,
  0x6f,0x72,0x20,0x28,0x76,0x61,0x72,0x20,0x69,0x20,0x3d,0x20,0x30,0x2c,0x20,0x63,
  0x6f,0x75,0x6e,0x74,0x20,0x3d,0x20,0x66,0x6f,0x6c,0x64,0x65,0x72,0x73,0x2e,0x6c,
  0x65,0x6e,0x67,0x74,0x68,0x3b,0x20,0x69,0x20,0x21,0x3d,0x3d,0x20,0x63,0x6f,0x75,
  0x6e,0x74,0x3b,0x20,0x2b,0x2b,0x69,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x76,0x61,0x72,0x20,0x66,0x6f,0x6c,0x64,0x65,0x72,0x20,0x3d,0x20,
  0x66,0x6f,0x6c,0x64,0x65,0x72,0x73,0x5b,0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x69,0x66,0x20,0x28,0x66,0x6f,0x6c,0x64,0x65,0x72,0x2e,0x69,
  0x64,0x20,0x3d,0x3d,0x3d,0x20,0x69,0x64,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x72,0x65,0x74,0x75,0x72,0x6e,0x20,0x66,
  0x6f,0x6c,0x64,0x65,0x72,0x3b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,
  0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x7d,0xa,0xa,0x66,0x75,0x6e,0x63,0x74,0x69,
  0x6f,0x6e,0x20,0x66,0x69,0x6e,0x64,0x44,0x65,0x76,0x69,0x63,0x65,0x28,0x6e,0x61,
  0x6d,0x65,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,0x61,0x72,0x20,0x64,0x65,
  0x76,0x69,0x63,0x65,0x73,0x20,0x3d,0x20,0x63,0x6f,0x6e,0x66,0x69,0x67,0x2e,0x64,
  0x65,0x76,0x69,0x63,0x65,0x73,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,0x6f,0x72,0x20,
  0x28,0x76,0x61,0x72,0x20,0x69,0x20,0x3d,0x20,0x30,0x2c,0x20,0x63,0x6f,0x75,0x6e,
  0x74,0x20,0x3d,0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x73,0x2e,0x6c,0x65,0x6e,0x67,
  0x74,0x68,0x3b,0x20,0x69,0x20,0x21,0x3d,0x3d,0x20,0x63,0x6f,0x75,0x6e,0x74,0x3b,
  0x20,0x2b,0x2b,0x69,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x76,0x61,0x72,0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x20,0x3d,0x20,0x64,0x65,0x76,
  0x69,0x63,0x65,0x73,0x5b,0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x69,0x66,0x20,0x28,0x64,0x65,0x76,0x69,0x63,0x65,0x2e,0x6e,0x61,0x6d,0x65,
  0x20,0x3d,0x3d,0x3d,0x20,0x6e,0x61,0x6d,0x65,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x72,0x65,0x74,0x75,0x72,0x6e,0x20,
  0x64,0x65,0x76,0x69,0x63,0x65,0x3b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x7d,0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x7d,0xa,0xa,0x66,0x75,0x6e,0x63,0x74,
  0x69,0x6f,0x6e,0x20,0x66,0x69,0x6e,0x64,0x44,0x65,0x76,0x69,0x63,0x65,0x42,0x79,
  0x49,0x64,0x28,0x69,0x64,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x76,0x61,0x72,
  0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x73,0x20,0x3d,0x20,0x63,0x6f,0x6e,0x66,0x69,
  0x67,0x2e,0x64,0x65,0x76,0x69,0x63,0x65,0x73,0x3b,0xa,0x20,0x20,0x20,0x20,0x66,
  0x6f,0x72,0x20,0x28,0x76,0x61,0x72,0x20,0x69,0x20,0x3d,0x20,0x30,0x2c,0x20,0x63,
  0x6f,0x75,0x6e,0x74,0x20,0x3d,0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x73,0x2e,0x6c,
  0x65,0x6e,0x67,0x74,0x68,0x3b,0x20,0x69,0x20,0x21,0x3d,0x3d,0x20,0x63,0x6f,0x75,
  0x6e,0x74,0x3b,0x20,0x2b,0x2b,0x69,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x76,0x61,0x72,0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x20,0x3d,0x20,
  0x64,0x65,0x76,0x69,0x63,0x65,0x73,0x5b,0x69,0x5d,0x3b,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x69,0x66,0x20,0x28,0x64,0x65,0x76,0x69,0x63,0x65,0x2e,0x64,
  0x65,0x76,0x69,0x63,0x65,0x49,0x44,0x20,0x3d,0x3d,0x3d,0x20,0x6e,0x61,0x6d,0x65,
  0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x72,0x65,0x74,0x75,0x72,0x6e,0x20,0x64,0x65,0x76,0x69,0x63,0x65,0x3b,0xa,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x7d,
  0xa,0xa,0x66,0x75,0x6e,0x63,0x74,0x69,0x6f,0x6e,0x20,0x61,0x73,0x73,0x69,0x67,
  0x6e,0x49,0x66,0x50,0x72,0x65,0x73,0x65,0x6e,0x74,0x28,0x6f,0x62,0x6a,0x65,0x63,
  0x74,0x2c,0x20,0x70,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x2c,0x20,0x76,0x61,0x6c,
  0x75,0x65,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x69,0x66,0x20,0x28,0x21,0x6f,
  0x62,0x6a,0x65,0x63,0x74,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x72,0x65,0x74,0x75,0x72,0x6e,0x3b,0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,
  0x20,0x20,0x20,0x6f,0x62,0x6a,0x65,0x63,0x74,0x5b,0x70,0x72,0x6f,0x70,0x65,0x72,
  0x74,0x79,0x5d,0x20,0x3d,0x20,0x76,0x61,0x6c,0x75,0x65,0x3b,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // js
  0x0,0x2,
  0x0,0x0,0x7,0x13,
  0x0,0x6a,
  0x0,0x73,
    // helper.js
  0x0,0x9,
  0x3,0x6c,0x88,0x93,
  0x0,0x68,
  0x0,0x65,0x0,0x6c,0x0,0x70,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,0x6a,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0x94,0xfa,0x24,0xa0,
  // :/js
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0x94,0xfa,0x24,0xa0,
  // :/js/helper.js
  0x0,0x0,0x0,0xa,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0x94,0xfa,0x24,0xa0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_js)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_js)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_js)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_js)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_js)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_js)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
